package Task::Elkhound;

use 5.005;
use strict;
use warnings;

our $VERSION = '0.03';
 
1;
__END__


=head1 NAME

Task::Elkhound - Perl extension for installing Moose and dependencies

=head1 VERSION
 
Task::Elkhound 0.03

=head1 SYNOPSIS

cpan Task::Elkhound

=head1 DESCRIPTION

Installs dependencies of Moose and Task::Moose

=head2 EXPORT

None by default.

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2012 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, and any later 
version of Perl 5 you may have available.


=cut
